/**
 * @ingroup as68
 */

/**
 * @defgroup  as68 as68
 *
 * @brief     as68 MC68000 Macro Assembler.
 *
 * as68 is a very fast Motorola 68000 macro assembler.
 *  
 *  This program is free software.
 *
 * @author  Copyright (C) 1993-2001 Vincent Penne and Ben(jamin) Gerard
 * @date    1993
 *
 *  @par Usages:
 *  as68 [-rRvVb] <in> [-o <out>] [-s <symbol>]
 *
 *  @par Options:
 *
 *  @arg @b -r             Do not produce relocation table (default)
 *  @arg @b -R             Produce relocation table
 *  @arg @b -p             No position independant code check (default)
 *  @arg @b -P             Warning position dependant addressing mode
 *  @arg @b -v             Disable verbose
 *  @arg @b -V             Enable Verbose (default)
 *  @arg @b -b[Kbytes]     Change code buffer (Kbytes is a number of Kbyte)
 *  @arg @b -s <filename>  Set relocation table filename (def:<in>.rel)
 *  @arg @b -o <filename>  Set output filename (def:<in>.bin) 
 *
 *  @par Assembler syntax:
 *
 *  as68 syntax is very close to hisoft genst(tm). 
 *  Except for some assembly directives are which are followed by a
 *  { ... } block. 
 *
 *  @par Macros syntax:
 *
 *  as68 macro processor is not compatible with hisoft genst (tm). 
 *  
 *  @code
 *     name MACRO
 *     {
 *       move.l #\1,d0  ;\1 is the first macro parameter
 *     }
 *  @endcode
 *
 *
 *  @par Assembler control directives:
 *
 *  @arg @b PRINT        [EXPR] Output a message
 *  @arg @b REPEAT       Start a repeat ... until loop.
 *  @arg @b RPT          as @b REPEAT
 *  @arg @b WHILE        [EXPR] Start a while block
 *  @arg @b IF           [EXPR] Start a conditionnal block
 *  @arg @b INCBIN       [FILE] Include binary file.
 *  @arg @b INCLUDE      [FILE] Include source file.
 *  @arg @b ORG          [EXPR] Set assembly address.
 *  @arg @b DEFAULT      [BYTE|WORD]  Set default opcode size.
 *  @arg @b EVEN         Set align to next even position
 *  @arg @b ALIGN        [EXPR] Set align to given position
 *  @arg @b RSRESET      Reset current structure.
 *  @arg @b RSSET        Add a field to current structure
 *  @arg @b LOAD         [EXPR] Set load address (cross devel)
 *  @arg @b RUN          [EXPR] Set run address (cross devel)
 *  @arg @b LS           [FILE] Load symbol. 
 *  @arg @b LST          [FILE] Load symbol 2!
 *  @arg @b RELOCATION   [on|off] Set relocation generation
 *
 *  @bug  Missing relocation.
 *  @bug  -P forces -R. @b org directive is disabled !!
 *  @bug  pea relatif PC, bugs with -P or -R
 *  @bug  symbol created by  xx = v are always lower case !
 */
