/**
 * @ingroup   desa68_devel
 * @author    Ben(jamin) Gerard <ben@sashipa.com>
 * @file      desa68.h
 * @date      17/03/1999
 * @brief     Motorola 68K disassembler
 * @version   $Id$
 */

/*
 *                        sc68 - 68000 disassembler
 *         Copyright (C) 2001 Ben(jamin) Gerard <ben@sashipa.com>
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by the
 *  Free Software Foundation; either version 2 of the License, or (at your
 *  option) any later version.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _DESA68_H_
#define _DESA68_H_

#ifdef __cplusplus
extern "C" {
#endif

#ifndef EMU68DEBUG
#define EMU68DEBUG
#endif

/** 68K disassemble pass parameters.
 *
 *    The DESA68parm_t data structure contains the information necessary to
 *    disassemble 68K instructions.
 *    - mem68 and memmsk define 68K memory buffer.
 *    - pc is the address of instruction to disassemble in 68K memory. It is
 *      incremented to next instruction by disassembler.
 *    - str and strmax define string receiving disassembly instruction.
 *    - others fields are for internal use only.
 */
typedef struct
{
  unsigned char *mem;     /**< Base of 68K memory                */
  unsigned int  memmsk;   /**< Size of memory - 1 (mask)         */
  unsigned int  pc;       /**< Offset to area to disassemble     */
  int w;                  /**< Last word decoded (sign extended) */

  char *str;    /**< Destination string */
  int  strmax;	/**< Destination maximum size in byte */
  char *s;		  /**< Pointer to current destination char @internal */

  /* Intermediat opcode decoding */
  int	reg0;       /**< @internal */
  int	reg9;       /**< @internal */
  int	mode3;      /**< @internal */
  int	mode6;      /**< @internal */
  int	opsz;       /**< @internal */
  int	line;       /**< @internal */
  int	adrmode0;   /**< @internal */
  int	adrmode6;   /**< @internal */
  int	szchar;     /**< @internal */

} DESA68parm_t;

/** Disassemble a single 68000 instruction.
 *
 *    param  d  Pointer to disassemble pass parameter structure.
 */
void desa68(DESA68parm_t *d);

#ifdef __cplusplus
}
#endif

#endif /* #ifndef _DESA68_H_ */
