/**
 * @ingroup   winamp68_devel
 * @file      fileinfo.c
 * @author    Ben(jamin) Gerard <ben@sashipa.com>
 * @date      06/11/2000
 * @brief     sc68 file info dialog box.
 * @version   $Id$
 */

/*
 *                         sc68 - Disk file access
 *         Copyright (C) 2001 Ben(jamin) Gerard <ben@sashipa.com>
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by the
 *  Free Software Foundation; either version 2 of the License, or (at your
 *  option) any later version.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include <windows.h>
#include <mmreg.h>
#include <msacm.h>
#include <math.h>
#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <commctrl.h>
#include <time.h>
#include "resource.h"
#include "in2.h"

#include "file68/SC68utils.h"
#include "file68/SC68file.h"


extern In_Module mod; // the output module (declared in winamp68.c)

BOOL CALLBACK DialogProc(HWND,UINT,WPARAM,LPARAM);

// Only exported function. We don't really need an header file for this !
int CreateFileInfoDialog(char *fn, HWND hwnd)
{
  HWND hdlg;
  hdlg = CreateDialogParam(mod.hDllInstance, (LPCTSTR)IDD_FILEINFO, hwnd,
                           (DLGPROC)DialogProc,(LPARAM) fn);
  return hdlg ? 0 : -1;
}

static int SetText(HWND hdlg, int id, const char *new_text)
{
  LRESULT res;
  WPARAM wParam = 0;
  LPARAM lParam = (LPARAM)new_text;
  res = SendDlgItemMessage(hdlg, id, WM_SETTEXT, wParam, lParam);
  return (!!res);
}

static int SetIconText(HWND hdlg, int id, const char *new_text)
{
  return SetText(hdlg, id, new_text);
}

static int SetIconFormat(HWND hdlg, int id, const char *format, int n)
{
  char buffer[64];
  _snprintf(buffer,sizeof(buffer), format, n);
  buffer[sizeof(buffer)-1] = 0;
  return SetText(hdlg, id, buffer);
}


static int SetEnable(HWND hdlg, int id, int enable)
{
  LRESULT res;
  res = SendDlgItemMessage(hdlg, id, BM_SETCHECK, !!enable, 0);
  EnableWindow(GetDlgItem(hdlg,id),!!enable);
  return (!!res);
}

static int SetTrackInfo(HWND hdlg, disk68_t *d, int trackNum)
{
  music68_t *m = 0;

  if (d && d->nb_six>0) {
    trackNum %= d->nb_six;
    m = d->mus + trackNum;
    SetIconText(hdlg, IDC_TNAME, m->name);
    SetIconText(hdlg, IDC_TAUTHOR, m->author);
    SetIconText(hdlg, IDC_TCOMPOSER, m->composer);
    SetIconText(hdlg, IDC_TTIME, SC68utils_make_track_time_info(trackNum+1, m->time));
    SetIconText(hdlg, IDC_TREPLAY, m->replay ? m->replay : " internal");
    SetIconFormat(hdlg, IDC_TRATE, " %d Hz",m->frq);
    SetIconFormat(hdlg, IDC_TLOADADDR, " $%X", m->a0);
    SetEnable(hdlg, IDC_HWYM,  m->flags.ym);
    SetEnable(hdlg, IDC_HWMW,  m->flags.ste);
    SetEnable(hdlg, IDC_HWAGA, m->flags.amiga);
  }
  return 0;
}

// Change cookie, return previous
static disk68_t * ChangeDisk(HWND hdlg, disk68_t *d)
{
  return (disk68_t * )SetWindowLong(hdlg, DWL_USER, (LONG)d);
}

// Get cookie
static disk68_t * GetDisk(HWND hdlg)
{
  return (disk68_t *)GetWindowLong(hdlg, DWL_USER);
}

static const char *endMsg[] =
{
  "I want my Atari ST back",
  "Did he say Amiga ???",
  "You can't beat the feeling",
};

static int SetDiskInfo(HWND hdlg, char *fn)
{
  static const char *error = "Not an sc68 file";
  disk68_t *d;
  int min = 0, max = 0, pos = 0;
  SetIconText(hdlg,IDC_FNAME, fn);
  d = GetDisk(hdlg);
  if (d) {
    SetIconText(hdlg,IDC_DNAME, d->name);
    SetIconText(hdlg,IDC_DTIME, SC68utils_make_track_time_info(d->nb_six, d->time));
    SetTrackInfo(hdlg, d, d->default_six);
    max = d->nb_six-1;
    pos = d->default_six;
  } else {
    SetIconText(hdlg,IDC_DNAME, error);
    SetIconText(hdlg,IDC_DTIME, SC68utils_make_track_time_info(-1,-1));
    SetTrackInfo(hdlg, 0, 0);
  }
  SendDlgItemMessage(hdlg, IDC_TUP,UDM_SETRANGE32, min, max);
  SendDlgItemMessage(hdlg, IDC_TUP,UDM_SETPOS, 0, (LPARAM) MAKELONG((short)pos, 0));

  SetIconText(hdlg, IDOK, endMsg[rand() % (sizeof(endMsg)/ sizeof(*endMsg))]);
  SetFocus(GetDlgItem(hdlg, IDC_TUP));
  return 0;
}

static int ChangeFile(HWND hdlg, char *fn)
{
  disk68_t *d, *prev;
  d = SC68file_load(fn);
  if (!d) {
    return -1;
  }
  prev = ChangeDisk(hdlg, d);
  if (prev) {
    SC68_free(prev);
  }
  SetDiskInfo(hdlg, fn);
  return 0;
}

static BOOL CALLBACK DialogProc(
  HWND hdlg,      // handle to dialog box
  UINT uMsg,      // message
  WPARAM wParam,  // first message parameter
  LPARAM lParam   // second message parameter
)
{

  switch(uMsg) {
		case WM_INITDIALOG:
      {
        srand((int)hdlg+((int)lParam<<5)^(int)time(0));  // For the "funny" message in IDOK button
        ChangeFile(hdlg, (char *)lParam);
        ShowWindow(hdlg, SW_SHOW);
        UpdateWindow(hdlg);
      } return 1;

    case WM_COMMAND:
      {
        int wNotifyCode = HIWORD(wParam); // notification code
        int wID = LOWORD(wParam);         // item, control, or accelerator identifier
        HWND hwndCtl = (HWND) lParam;     // handle of control

        switch(wID) {
          case IDOK:
            DestroyWindow (hdlg);
            break;
        }
      } return 0;

    case WM_VSCROLL:
      {
        int nScrollCode = (int) LOWORD(wParam);   // scroll bar value
        short nPos = (short int) HIWORD(wParam);  // scroll box position
        HWND hwndScrollBar = (HWND) lParam;       // handle to scroll bar
        if (hwndScrollBar != GetDlgItem(hdlg, IDC_TUP)) {
          return 0; // Safe net, should not happen.
        } else {
          disk68_t *d;
          d = (disk68_t *) GetWindowLong(hdlg, DWL_USER);
          if (!d) {
            return 0;
          }

          switch (nScrollCode) {
            case SB_THUMBPOSITION:
              SetTrackInfo(hdlg, d, nPos);
              break;
          }
        }
      } return 0;

		case WM_DESTROY:
      {
        disk68_t *d;
        d = ChangeDisk(hdlg,0);
        if (d) {
          SC68_free(d);
        }
      } return 0;

		case WM_CLOSE:
			DestroyWindow (hdlg);
			return 0;

  }

  return 0;
}



